EasingCurveEditor

Struct EasingCurveEditor 

pub struct EasingCurveEditor {
    pub current: Easing,
    pub compare: Option<Easing>,
    pub sample_count: usize,
}
Interactive easing curve editor.

Fields

current: Easing

Current easing curve.

compare: Option<Easing>

Optional comparison curve.

sample_count: usize

Number of sample points used for rendering.

Implementations

Source

impl EasingCurveEditor

pub fn new(easing: Easing) -> Self

Create an editor for an easing curve.

pub fn set_easing(&mut self, easing: Easing)

Set the primary easing.

pub fn set_compare(&mut self, easing: Option<Easing>)

Set an optional comparison easing.

pub fn set_sample_count(&mut self, sample_count: usize)

Set curve sampling resolution. Values below two are clamped.

pub fn samples(&self) -> Vec<[f32; 2]>

Return sample points for the current easing.

pub fn samples_into(&self, out: &mut Vec<[f32; 2]>)

Write sample points for the current easing into a reusable buffer.

pub fn compare_samples(&self) -> Option<Vec<[f32; 2]>>

Return sample points for the comparison easing.

pub fn set_control_points(&mut self, x1: f32, y1: f32, x2: f32, y2: f32)

Update cubic-bezier control points and make them the current easing.

pub fn copy_code(&self) -> String

Return Rust code for the current easing.